@@ -21,7 +21,7 @@ class SessionManagerFixedTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void test_maximumNumberOfNewWordsPerSession_written();
